summaryrefslogtreecommitdiff
path: root/poezio/tabs/muctab.py
diff options
context:
space:
mode:
Diffstat (limited to 'poezio/tabs/muctab.py')
-rw-r--r--poezio/tabs/muctab.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/poezio/tabs/muctab.py b/poezio/tabs/muctab.py
index d77aaf39..d71656b6 100644
--- a/poezio/tabs/muctab.py
+++ b/poezio/tabs/muctab.py
@@ -124,14 +124,14 @@ class MucTab(ChatTab):
def cancel_config(self, form):
"""
The user do not want to send his/her config, send an iq cancel
"""
muc.cancel_config(self.core.xmpp, self.name)
self.core.close_tab()
def send_config(self, form):
"""
The user sends his/her config to the server
"""
muc.configure_room(self.core.xmpp, self.name, form)
self.core.close_tab()
@@ -2053,7 +2053,7 @@ class MucTab(ChatTab):
'usage':
'<nickname>',
'desc': ('Display some information about the user '
- 'in the MUC: its/his/her role, affiliation,'
+ 'in the MUC: their role, affiliation,'
' status and status message.'),
'shortdesc':
'Show an user\'s infos.',
@@ -124,14 +124,14 @@ class MucTab(ChatTab):
def cancel_config(self, form):
"""
- The user do not want to send his/her config, send an iq cancel
+ The user do not want to send their config, send an iq cancel
"""
muc.cancel_config(self.core.xmpp, self.name)
@@ -124,14 +124,14 @@ class MucTab(ChatTab):
def send_config(self, form):
"""
- The user sends his/her config to the server
+ The user sends their config to the server
"""
muc.configure_room(self.core.xmpp, self.name, form)